@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "warning.h"
 
@@ -11,7 +11,7 @@ protected:
   int overflow(int c) { return EOF; }
 };
 
-std::ostream cerr_Alias::null(new NullFdBuf());
+std::ostream cerrAlias::null(new NullFdBuf());
 
 // The actual alias streams.  The constructor arg is default visibility.
-cerr_Alias warning(true), verbose(false), debug(false);
+cerrAlias warning(true), verbose(false), debug(false);
